##  Archiving a Fact Sheet
To archive a fact sheet in SAP LeanIX, follow these steps:
  1. Open the fact sheet you want to archive.
  2. From the menu at the top right corner, select Archive.
  3. You are prompted to specify a reason for archiving the fact sheet. This helps enhance transparency and understanding for other users. Provide the explanation.
  4. Click Archive.


![Archiving a Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274296857a441014a81bb4b52e57ffe5_LowRes.png)
Archiving a Fact Sheet
